@@ -1,7 +1,7 @@
 package Complete::Util;
 
-our $DATE = '2016-04-05'; # DATE
-our $VERSION = '0.46'; # VERSION
+our $DATE = '2016-08-24'; # DATE
+our $VERSION = '0.47'; # VERSION
 
 use 5.010001;
 use strict;
@@ -17,6 +17,7 @@ our @EXPORT_OK = qw(
                        combine_answers
                        complete_array_elem
                        complete_hash_key
+                       complete_comma_sep
                );
 
 our %SPEC;
@@ -140,6 +141,33 @@ sub __editdist {
     $d[@a][@b];
 }
 
+my %complete_array_elem_args = (
+    %arg_word,
+    array       => {
+        schema => ['array*'=>{of=>'str*'}],
+        req => 1,
+    },
+    exclude     => {
+        schema => ['array*'],
+    },
+    replace_map => {
+        schema => ['hash*', each_value=>['array*', of=>'str*']],
+        description => <<'_',
+
+You can supply correction entries in this option. An example is when array if
+`['mount','unmount']` and `umount` is a popular "typo" for `unmount`. When
+someone already types `um` it cannot be completed into anything (even the
+current fuzzy mode will return *both* so it cannot complete immediately).
+
+One solution is to add replace_map `{'unmount'=>['umount']}`. This way, `umount`
+will be regarded the same as `unmount` and when user types `um` it can be
+completed unambiguously into `unmount`.
+
+_
+        tags => ['experimental'],
+    },
+);
+
 $SPEC{complete_array_elem} = {
     v => 1.1,
     summary => 'Complete from array',
@@ -156,30 +184,7 @@ Will sort the resulting completion list, so you don't have to presort the array.
 
 _
     args => {
-        %arg_word,
-        array       => {
-            schema => ['array*'=>{of=>'str*'}],
-            req => 1,
-        },
-        exclude     => {
-            schema => ['array*'],
-        },
-        replace_map => {
-            schema => ['hash*', each_value=>['array*', of=>'str*']],
-            description => <<'_',
-
-You can supply correction entries in this option. An example is when array if
-`['mount','unmount']` and `umount` is a popular "typo" for `unmount`. When
-someone already types `um` it cannot be completed into anything (even the
-current fuzzy mode will return *both* so it cannot complete immediately).
-
-One solution is to add replace_map `{'unmount'=>['umount']}`. This way, `umount`
-will be regarded the same as `unmount` and when user types `um` it can be
-completed unambiguously into `unmount`.
-
-_
-            tags => ['experimental'],
-        },
+        %complete_array_elem_args,
     },
     result_naked => 1,
     result => {
@@ -390,6 +395,73 @@ sub complete_hash_key {
     );
 }
 
+my %complete_comma_sep_args = (
+    %complete_array_elem_args,
+    sep => {
+        schema  => 'str*',
+        default => ',',
+    },
+    uniq => {
+        summary => 'Whether list contains unique elements',
+        schema => ['str*', is=>1],
+    },
+);
+$complete_comma_sep_args{elems} = delete $complete_comma_sep_args{array};
+
+$SPEC{complete_comma_sep} = {
+    v => 1.1,
+    summary => 'Complete a comma-separated list string',
+    args => {
+        %complete_comma_sep_args,
+    },
+    result_naked => 1,
+    result => {
+        schema => 'array',
+    },
+};
+sub complete_comma_sep {
+    my %args  = @_;
+    my $word      = delete $args{word} // "";
+    my $sep       = delete $args{sep} // ',';
+    my $elems     = delete $args{elems} or die "Please specify elems";
+    my $uniq      = delete $args{uniq};
+
+    my $ci = $Complete::Common::OPT_CI;
+
+    my @mentioned_elems = split /\Q$sep\E/, $word, -1;
+    my $cae_word = @mentioned_elems ? pop(@mentioned_elems) : '';
+
+    my @unmentioned_elems;
+    {
+        last unless $uniq;
+        my %mem;
+        for (@mentioned_elems) {
+            if ($ci) { $mem{lc $_}++ } else { $mem{$_}++ }
+        }
+        for (@$elems) {
+            push @unmentioned_elems, $_ unless ($ci ? $mem{lc $_} : $mem{$_});
+        }
+    }
+
+    my $cae_res = complete_array_elem(
+        %args,
+        word  => $cae_word,
+        array => ($uniq ? \@unmentioned_elems : $elems),
+    );
+
+    my $prefix = join($sep, @mentioned_elems);
+    $prefix .= $sep if @mentioned_elems;
+    $cae_res = [map { "$prefix$_" } @$cae_res];
+
+    # add trailing comma for convenience, where appropriate
+    {
+        last unless @$cae_res == 1;
+        last if $uniq && @unmentioned_elems <= 1;
+        $cae_res->[0] .= $sep;
+    }
+    $cae_res;
+}
+
 $SPEC{combine_answers} = {
     v => 1.1,
     summary => 'Given two or more answers, combine them into one',
@@ -514,7 +586,7 @@ Complete::Util - General completion routine
 
 =head1 VERSION
 
-This document describes version 0.46 of Complete::Util (from Perl distribution Complete-Util), released on 2016-04-05.
+This document describes version 0.47 of Complete::Util (from Perl distribution Complete-Util), released on 2016-08-24.
 
 =head1 DESCRIPTION
 
@@ -619,6 +691,46 @@ Word to complete.
 Return value:  (array)
 
 
+=head2 complete_comma_sep(%args) -> array
+
+Complete a comma-separated list string.
+
+This function is not exported by default, but exportable.
+
+Arguments ('*' denotes required arguments):
+
+=over 4
+
+=item * B<elems>* => I<array[str]>
+
+=item * B<exclude> => I<array>
+
+=item * B<replace_map> => I<hash>
+
+You can supply correction entries in this option. An example is when array if
+C<['mount','unmount']> and C<umount> is a popular "typo" for C<unmount>. When
+someone already types C<um> it cannot be completed into anything (even the
+current fuzzy mode will return I<both> so it cannot complete immediately).
+
+One solution is to add replace_map C<< {'unmount'=E<gt>['umount']} >>. This way, C<umount>
+will be regarded the same as C<unmount> and when user types C<um> it can be
+completed unambiguously into C<unmount>.
+
+=item * B<sep> => I<str> (default: ",")
+
+=item * B<uniq> => I<str>
+
+Whether list contains unique elements.
+
+=item * B<word>* => I<str> (default: "")
+
+Word to complete.
+
+=back
+
+Return value:  (array)
+
+
 =head2 complete_hash_key(%args) -> array
 
 Complete from hash keys.
